import { InternalAxiosRequestConfig, AxiosInstance, AxiosResponse, AxiosRequestConfig } from 'axios';

type ErrorMessageMode = 'modal' | 'message' | 'notice' | undefined;
type SuccessMessageMode = ErrorMessageMode;
interface RequestOptions {
    joinParamsToUrl?: boolean;
    formatDate?: boolean;
    isTransformResponse?: boolean;
    isReturnNativeResponse?: boolean;
    joinPrefix?: boolean;
    apiUrl?: string;
    urlPrefix?: string;
    errorMessageMode?: ErrorMessageMode;
    successMessageMode?: SuccessMessageMode;
    getContainer?: () => HTMLElement | null;
    zIndex?: number;
    joinTime?: boolean;
    ignoreCancelToken?: boolean;
    withToken?: boolean;
    customSuccessMessage?: string;
    closeErrorModal?: boolean;
}
interface CreateAxiosOptions extends AxiosRequestConfig {
    authenticationScheme?: string;
    requestOptions?: RequestOptions;
    apiUrl?: string;
    urlPrefix?: string;
    timeout?: number;
}
interface VAxiosPlugin {
    pluginName: string;
    requestInterceptors?: (config: InternalAxiosRequestConfig, options: CreateAxiosOptions, axiosInstance: AxiosInstance) => InternalAxiosRequestConfig;
    requestInterceptorsCatch?: (error: Error) => void;
    responseInterceptors?: (axiosInstance: AxiosInstance, AxiosResponse: AxiosResponse, requestOptions: RequestOptions) => AxiosResponse<any>;
    responseInterceptorsCatch?: (axiosInstance: AxiosInstance, error: any, requestOptions: RequestOptions) => void;
}
type LocaleType = 'zh_CN' | 'en_US';

type EventHandler = (...args: any[]) => void;
type EventType = 'axiosError401' | 'axiosGetToken';
declare class EventBus {
    private events;
    constructor();
    on(eventHandlers: Array<{
        [key in EventType]?: EventHandler;
    }>): void;
    off(eventHandlers: Array<{
        [key in EventType]?: EventHandler;
    }>): void;
    emit(event: EventType, ...args: any[]): Array<any> | void;
}
declare const axiosEvent: EventBus;

interface VAxiosOptions {
    locale: LocaleType;
}

declare function axiosReactPresent(VAxiosOptions: VAxiosOptions): VAxiosPlugin;

export { type VAxiosOptions, type VAxiosPlugin, axiosEvent, axiosReactPresent };
